using Newtonsoft.Json;
using Syncfusion.DataSource;
using Syncfusion.ListView.XForms;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Runtime.CompilerServices;
using System.Text;
using TurnaApp.Model;
using TurnaApp.View;
using Xamarin.Forms;

namespace TurnaApp.ViewModel
{
    public class BudgetPageViewModel : INotifyPropertyChanged
    {
        #region Command Fields

        Command<SfListView> loadedCommand;
        Command<SfListView> selectionChangedCommand;

        #endregion

        #region Command Properties

        public Command<SfListView> LoadedCommand
        {
            get { return loadedCommand; }
            protected set { loadedCommand = value; }
        }

        public Command<SfListView> SelectionChangedCommand
        {
            get { return selectionChangedCommand; }
            protected set { selectionChangedCommand = value; }
        }

        #endregion

        private ObservableCollection<BudgetStatement> bsList;
        private string remark;

        public ObservableCollection<BudgetStatement> BsList
        {
            get { return bsList; }
            set { this.bsList = value; }
        }

        public string Remark
        {
            get
            {
                return remark;
            }
            set
            {
                if (remark == value)
                {
                    return;
                }
                remark = value;
                OnPropertyChanged();
            }
        }

        public BudgetPageViewModel()
        {
            loadedCommand = new Command<SfListView>(OnListViewLoaded);
            selectionChangedCommand = new Command<SfListView>(OnSelectionChanged);

            ExecuteAPI();
        }

        private async void ExecuteAPI()
        {
            bsList = new ObservableCollection<BudgetStatement>();

            try
            {
                TurnaManager turna = new TurnaManager();

                TurnaResponse response = await turna.GetBudgetStatOverall(1);

                if (response.Level == "INFO")
                {
                    bsList = JsonConvert.DeserializeObject<ObservableCollection<BudgetStatement>>(response.Data.ToString());
                }

            }
            catch (Exception ex)
            {

            }

        }

        public event PropertyChangedEventHandler PropertyChanged;

        protected virtual void OnPropertyChanged([CallerMemberName] string propertyName = null)
        {
            PropertyChanged?.Invoke(this, new PropertyChangedEventArgs(propertyName));
        }

        #region Command Events

        public void OnListViewLoaded(SfListView listView)
        {

        }

        private void OnSelectionChanged(SfListView listView)
        {
            var selectedItem = listView.SelectedItem;
            int selected = Convert.ToInt32(((BudgetStatement)selectedItem).FinancialPlan.ID);
            App.Current.MainPage.Navigation.PushAsync(new FinancialPage(selected));

            listView.SelectedItem = null;
        }

        #endregion
    }
}
