
using Newtonsoft.Json;
using Syncfusion.ListView.XForms;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Runtime.CompilerServices;
using System.Text;
using TurnaApp.Model;
using Xamarin.Forms;

namespace TurnaApp.ViewModel
{
    public class FinancialPageViewModel : INotifyPropertyChanged
    {
        #region Command Fields

        Command<SfListView> loadedCommand;
        Command<SfListView> selectionChangedCommand;

        #endregion

        #region Command Properties

        public Command<SfListView> LoadedCommand
        {
            get { return loadedCommand; }
            protected set { loadedCommand = value; }
        }

        public Command<SfListView> SelectionChangedCommand
        {
            get { return selectionChangedCommand; }
            protected set { selectionChangedCommand = value; }
        }

        #endregion

        private ObservableCollection<IncomeDetail> incomeList;
        private string remark;

        public ObservableCollection<IncomeDetail> IncomeList
        {
            get { return incomeList; }
            set { this.incomeList = value; }
        }

        public string Remark
        {
            get
            {
                return remark;
            }
            set
            {
                if (remark == value)
                {
                    return;
                }
                remark = value;
                OnPropertyChanged();
            }
        }

        public FinancialPageViewModel(int financialPlanId)
        {
            loadedCommand = new Command<SfListView>(OnListViewLoaded);
            selectionChangedCommand = new Command<SfListView>(OnSelectionChanged);

            ExecuteAPI(financialPlanId);
           
        }

        private async void ExecuteAPI(int financialPlanId)
        {
            incomeList = new ObservableCollection<IncomeDetail>();
            
            try
            {
                TurnaManager turna = new TurnaManager();

                TurnaResponse response = await turna.GetIncomeItems(financialPlanId);

                if (response.Level == "INFO")
                {
                    incomeList = JsonConvert.DeserializeObject<ObservableCollection<IncomeDetail>>(response.Data.ToString());

                }

            }
            catch (Exception ex)
            {

            }
        }

        public event PropertyChangedEventHandler PropertyChanged;

        protected virtual void OnPropertyChanged([CallerMemberName] string propertyName = null)
        {
            PropertyChanged?.Invoke(this, new PropertyChangedEventArgs(propertyName));
        }

        #region Command Events

        public void OnListViewLoaded(SfListView incomeView)
        {
            incomeView.ItemsSource = IncomeList;
            
        }

        private void OnSelectionChanged(SfListView incomeView)
        {

        }

        #endregion
    }
}
